# CHANGELOG

<!-- version list -->

## v1.0.1 (2026-01-11)

### Bug Fixes

- Improve release workflow dry run and prevent major version jumps
  ([#2](https://github.com/lan17/HomeSec/pull/2),
  [`ba02512`](https://github.com/lan17/HomeSec/commit/ba025129de5caa984552807e4e0f376666db485e))


## v1.0.0 (2026-01-11)

- Initial Release
